import { Buffer } from 'buffer/';
import { RawTransaction } from './aptos_types';
import { Bytes } from './bcs';
export declare type SigningMessage = Buffer;
export declare type TransactionSignature = Uint8Array;
/** Function that takes in a Signing Message (serialized raw transaction)
 *  and returns a signature
 */
export declare type SigningFn = (txn: SigningMessage) => TransactionSignature;
declare class TransactionBuilder<F extends SigningFn> {
    private readonly signingFunction;
    private readonly publicKey;
    constructor(signingFunction: F, publicKey: Uint8Array);
    /** Generates a Signing Message out of a raw transaction. */
    static getSigningMessage(rawTxn: RawTransaction): SigningMessage;
    private signInternal;
    /** Signs a raw transaction and returns a bcs serialized transaction. */
    sign(rawTxn: RawTransaction): Bytes;
}
/** Just a syntatic sugar.
 *  TODO: add default signing function for Ed25519 */
export declare class TransactionBuilderEd25519 extends TransactionBuilder<SigningFn> {
}
export {};
//# sourceMappingURL=index.d.ts.map